@@ -37,6 +37,7 @@ class Command(BaseCommand):
         --storage=[dropbox|file]
         --source=/path/to/photos (only when storage=file)
         --tags=peques,tag2,tag3
+        --thumbs=yes
 
     """
 
@@ -65,6 +66,12 @@ class Command(BaseCommand):
             default=default_tag,
             help='Tag(s) to add to photos --tag=tag1,tag2,tag3'
         ),
+        make_option(
+            '--thumbs',
+            dest='thumbs',
+            default=False,
+            help='Regenerate thumbnails for all the stored photos'
+        ),
     )
 
     def handle(self, *app_labels, **options):
@@ -127,20 +134,21 @@ class Command(BaseCommand):
                 total,
                 tags)
 
-        print ""
-        print "-"*80
-        print ""
-        print "[***] Making missing thumbs"
-        print ""
-        conf.THUMBNAIL_DEBUG = True
-        allphotos = mymodels.Photo.objects.all()
-        for i, p in enumerate(allphotos):
-            print "%04d - %s" % (i, p)
-            for thumb in thumbs:
-                c = Context({'image': p, 'thumb': "%sx%s" % (thumb, thumb)})
-                t = Template('{% load thumbnail %}{% thumbnail image thumb crop="top" as img %}{{ img.url }}{% endthumbnail %}')
-                t.render(c)
-                get_thumbnail(p, "%sx%s" % (thumb, thumb))
+        if options['thumbs'] == 'yes':
+            print ""
+            print "-"*80
+            print ""
+            print "[***] Making missing thumbs"
+            print ""
+            conf.THUMBNAIL_DEBUG = True
+            allphotos = mymodels.Photo.objects.all()
+            for i, p in enumerate(allphotos):
+                print "%04d - %s" % (i, p)
+                for thumb in thumbs:
+                    c = Context({'image': p, 'thumb': "%sx%s" % (thumb, thumb)})
+                    t = Template('{% load thumbnail %}{% thumbnail image thumb crop="top" as img %}{{ img.url }}{% endthumbnail %}')
+                    t.render(c)
+                    get_thumbnail(p, "%sx%s" % (thumb, thumb))
 
         print ""
         print "-"*80
